NLSL: parsav.f90 Source File

NLSL

- Main Page
- Modules
- Data Types List
- Files

- File List
- File Members

parsav.f90
Go to the documentation of this file.
1 c NLSL Version 1.9.0 beta 2/13/15
2 c----------------------------------------------------------------------
3 c =========================
4 c module PARSAV
5 c =========================
6 c
7 c Defines variables to be used for saving a copy of the working
8 c parameters and NLS search vector.
9 c
10 c Note: this module uses the nlsdim module.
11 c----------------------------------------------------------------------
12 c
13 module parsav
14 use nlsdim
15 implicit none
16 c
17 double precision, save :: fxsave(6,mxvar), fprsav(nfprm,mxsite),
18 # spsave(4,mxspc)
19 c
20 integer, save :: ixsave(3,mxvar), iprsav(niprm,mxsite),
21 # ixxsav(nfprm,mxsite), nstsav, nspsav, nprsav
22 c
23 logical, save :: xsaved, prsaved
24 c
25 character*9, save :: tagsav(mxvar)
26 c
27 end module parsav
parsav::spsave
double precision, dimension(4, mxspc), save spsave
Definition: parsav.f90:17
nlsdim::niprm
integer, parameter niprm
Definition: nlsdim.f90:57
parsav::prsaved
logical, save prsaved
Definition: parsav.f90:23
nlsdim::mxvar
integer, parameter mxvar
Definition: nlsdim.f90:39
parsav::xsaved
logical, save xsaved
Definition: parsav.f90:23
parsav::nstsav
integer, save nstsav
Definition: parsav.f90:20
parsav::tagsav
character *9, dimension(mxvar), save tagsav
Definition: parsav.f90:25
nlsdim::mxspc
integer, parameter mxspc
Definition: nlsdim.f90:39
parsav
Definition: parsav.f90:13
parsav::fprsav
double precision, dimension(nfprm, mxsite), save fprsav
Definition: parsav.f90:17
nlsdim::mxsite
integer, parameter mxsite
Definition: nlsdim.f90:39
parsav::nprsav
integer, save nprsav
Definition: parsav.f90:20
nlsdim
Definition: nlsdim.f90:36
parsav::ixxsav
integer, dimension(nfprm, mxsite), save ixxsav
Definition: parsav.f90:20
parsav::iprsav
integer, dimension(niprm, mxsite), save iprsav
Definition: parsav.f90:20
parsav::fxsave
double precision, dimension(6, mxvar), save fxsave
Definition: parsav.f90:17
parsav::nspsav
integer, save nspsav
Definition: parsav.f90:20
nlsdim::nfprm
integer, parameter nfprm
Definition: nlsdim.f90:57
parsav::ixsave
integer, dimension(3, mxvar), save ixsave
Definition: parsav.f90:20